function d=diffDivise(x,y)
%------------------------------
%Inputs
%     x=vettore dei valori x_i
%     y=vettore dei valori y_i 
% Output
%     d=vettore delle diffDivise
%-------------------------------
n=length(x);
d=y;
for i=1:n,
    if i~=1
        for j=2:i,
            d(i)=(d(i)-d(j-1))/(x(i)-x(j-1));
        end
    end
end
